% This file implements the method described in:
%
% "Consistent Partial Matching of Shape Collections via Sparse Modeling" 
% L. Cosmo, E. Rodola, A. Albarelli, F. Memoli, D. Cremers
% Computer Graphics Forum, 2016
%
% If you use this code, please cite the paper above.
% 
% Luca Cosmo, Emanuele Rodola (c) 2015

function D = geo_dist_between_samples(M,samples)
%% Computes the geodesic distance between the given samples of the 
%  triangulated manifold M.
%  Input:
%  - M: the shape (triangluated manifold)
%  - samples: indexes of the points between which calculate the distance
%  Output.
%  - D: the distance matrix

geo = fastmarchmex('init', int32(M.TRIV-1), double(M.VERT(:,1)), double(M.VERT(:,2)), double(M.VERT(:,3)));

vals = zeros(length(samples));
for k=1:length(samples)
    s = inf(M.n,1);
    s(samples(k)) = 0;
    d = fastmarchmex('march', geo, double(s));       
    vals(k,:) = d(samples);
end

D = 0.5*(vals+vals');
fastmarchmex('deinit', geo);