% This file implements the method described in:
%
% "Consistent Partial Matching of Shape Collections via Sparse Modeling" 
% L. Cosmo, E. Rodola, A. Albarelli, F. Memoli, D. Cremers
% Computer Graphics Forum, 2016
%
% If you use this code, please cite the paper above.
% 
% Luca Cosmo, Emanuele Rodola (c) 2015

function T = build_validation_matrix(shapes, matches, params)
%% Computes the similarity between the given mw-matches according to the 
%  adopted geodesic distance distortion metric.
%  Input: 
%  - shapes: a collection of shapes
%  - matches: a cell array contining mw-matches
%  - params: optimization parameters

    all_matches = cat(1,matches{:});
    D = cell(1, length(shapes));
    full2fps = cell(1, length(shapes));

    parfor i=1:length(shapes)
        n = shapes{i}.n;
        sources = all_matches(all_matches(:,1)==i , 2);
        sources = unique(sources);
%         fps2full{i} = sources;
        full2fps{i} = zeros(1,n);
        full2fps{i}(sources) = 1:numel(sources);
        %fprintf('Sources: %d\n', length(sources));

        D{i} = geo_dist_between_samples(shapes{i},sources);
    end

    %%Store tracks in a matrix padded with zeros
    M = zeros(numel(matches),numel(shapes));
    for i=1:length(matches)
        M(i,matches{i}(:,1))=matches{i}(:,2)';
    end
    for i=1:size(M,2)
        valid = M(:,i)>0;
        M(valid,i) = full2fps{i}(M(valid,i));
    end
    %%

    T=track_similarity(int32(M'),D,params.min_overlap,params.metric_sigma,params.distort_fun);
end