% This file implements the method described in:
%
% "Consistent Partial Matching of Shape Collections via Sparse Modeling" 
% L. Cosmo, E. Rodola, A. Albarelli, F. Memoli, D. Cremers
% Computer Graphics Forum, 2016
%
% If you use this code, please cite the paper above.
% 
% Luca Cosmo, Emanuele Rodola (c) 2015

function curve = calc_err_curve(errors, thresholds)
%% Compute the values of the error curve.
%  Input:
%  - errors: matching errors associated to each matched point.
%  - thresholds: error thresholds
%  Output:
%  - curve: vector containing the percentage of points with error below the
%           relative threshold value.

    curve = zeros(1, length(thresholds));
    for i=1:length(thresholds)
        curve(i) = 100*sum(errors <= thresholds(i)) / length(errors);
    end

end
