% This file implements the method described in:
%
% "Consistent Partial Matching of Shape Collections via Sparse Modeling" 
% L. Cosmo, E. Rodola, A. Albarelli, F. Memoli, D. Cremers
% Computer Graphics Forum, 2016
%
% If you use this code, please cite the paper above.
% 
% Luca Cosmo, Emanuele Rodola (c) 2015

function samples = get_shape_samples(shapes, query, params)
%% GET_SHAPE_SAMPLES extracts from the of each shape the k neares sampled 
%  points in the descriptor space. k is chosen according to the
%  params.samples_percentile parameter given as input.
%  Input:
%  - shapes: a collection of shapes
%  - query: a query point in the descriptor space
%  - params.descr: the used descriptor (wks|hks)
%  - params.samples_percentile: the percentile of points to be extracted
%  Returns:
%  - samples: a cell containing for each shape the vector of extracted
%             point indexes.

    samples = cell(1,length(shapes));
    for i=1:length(shapes)
        N = shapes{i};
        switch params.descr
            case 'wks'
                d = pdist2(query, N.WKS(N.fps,:));
            case 'hks'
                d = pdist2(query, N.HKS(N.fps,:));
        end

        [vals idx] = sort(d,'ascend');
        samples{i} = N.fps(idx(1:max(floor(numel(d)*params.samples_percentile./100),1)));
    end
end
